@@ -1,15 +1,15 @@
-# @(#)$Id: Config.pm 206 2012-09-06 17:31:12Z pjf $
+# @(#)$Id: Config.pm 223 2012-10-31 01:24:47Z pjf $
 
 package Class::Usul::Config;
 
 use strict;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 206 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 223 $ =~ /\d+/gmx );
 
 use Class::Usul::File;
 use Class::Usul::Moose;
 use Class::Usul::Constants;
 use Class::Usul::Functions       qw(app_prefix class2appdir home2appldir
-                                    split_on__ untaint_path);
+                                    is_arrayref split_on__ untaint_path);
 use Config;
 use English                      qw(-no_match_vars);
 use File::Basename               qw(basename dirname);
@@ -20,15 +20,9 @@ use File::Spec::Functions        qw(canonpath catdir catfile rel2abs tmpdir);
 has 'appclass'        => is => 'ro',   isa => NonEmptySimpleStr,
    required           => TRUE;
 
-has 'doc_title'       => is => 'ro',   isa => NonEmptySimpleStr,
-   default            => 'User Contributed Documentation';
-
 has 'encoding'        => is => 'ro',   isa => EncodingType, coerce => TRUE,
    default            => DEFAULT_ENCODING;
 
-has 'extension'       => is => 'ro',   isa => NonEmptySimpleStr,
-   default            => CONFIG_EXTN;
-
 has 'home'            => is => 'ro',   isa => Directory, coerce => TRUE,
    documentation      => 'Directory containing the config file',
    required           => TRUE;
@@ -39,15 +33,8 @@ has 'lock_attributes' => is => 'ro',   isa => HashRef, default => sub { {} };
 
 has 'log_attributes'  => is => 'ro',   isa => HashRef, default => sub { {} };
 
-has 'man_page_cmd'    => is => 'ro',   isa => ArrayRef,
-   default            => sub { [ qw(nroff -man) ] };
-
-has 'mode'            => is => 'ro',   isa => PositiveInt, default => MODE;
-
 has 'no_thrash'       => is => 'ro',   isa => PositiveInt, default => 3;
 
-has 'pathname'        => is => 'lazy', isa => File, coerce => TRUE;
-
 
 has 'appldir'         => is => 'lazy', isa => Directory, coerce => TRUE;
 
@@ -65,6 +52,8 @@ has 'logfile'         => is => 'lazy', isa => Path,      coerce => TRUE;
 
 has 'logsdir'         => is => 'lazy', isa => Directory, coerce => TRUE;
 
+has 'pathname'        => is => 'lazy', isa => File,      coerce => TRUE;
+
 has 'root'            => is => 'lazy', isa => Path,      coerce => TRUE;
 
 has 'rundir'          => is => 'lazy', isa => Path,      coerce => TRUE;
@@ -80,9 +69,9 @@ has 'tempdir'         => is => 'lazy', isa => Directory, coerce => TRUE;
 has 'vardir'          => is => 'lazy', isa => Path,      coerce => TRUE;
 
 
-has 'name'            => is => 'lazy', isa => NonEmptySimpleStr;
+has 'extension'       => is => 'lazy', isa => NonEmptySimpleStr;
 
-has 'owner'           => is => 'lazy', isa => NonEmptySimpleStr;
+has 'name'            => is => 'lazy', isa => NonEmptySimpleStr;
 
 has 'phase'           => is => 'lazy', isa => PositiveInt;
 
@@ -90,14 +79,11 @@ has 'prefix'          => is => 'lazy', isa => NonEmptySimpleStr;
 
 has 'salt'            => is => 'lazy', isa => NonEmptySimpleStr;
 
-has 'script'          => is => 'lazy', isa => NonEmptySimpleStr;
-
 around 'BUILDARGS' => sub {
    my ($next, $class, @args) = @_; my $attr = $class->$next( @args ); my $paths;
 
    if ($paths = delete $attr->{cfgfiles} and $paths->[ 0 ]) {
-      my $loaded = Class::Usul::File->data_load
-         ( paths => $paths, storage_class => q(Any), );
+      my $loaded = Class::Usul::File->data_load( paths => $paths );
 
       $attr = { %{ $loaded || {} }, %{ $attr } };
    }
@@ -117,6 +103,18 @@ around 'BUILDARGS' => sub {
    return $attr;
 };
 
+sub canonicalise {
+   my ($self, $base, $relpath) = @_;
+
+   my @base = ((is_arrayref $base) ? @{ $base } : $base);
+   my @rest = split m{ / }mx, $relpath;
+   my $path = canonpath( untaint_path catdir( @base, @rest ) );
+
+   -d $path and return $path;
+
+   return canonpath( untaint_path catfile( @base, @rest ) );
+}
+
 # Private methods
 
 sub _build_appldir {
@@ -131,17 +129,16 @@ sub _build_appldir {
 }
 
 sub _build_binsdir {
-   my ($self, $attr) = @_;
-
-   my $dir = $self->_inflate_path( $attr, qw(appldir bin) );
+   my $dir = $_[ 0 ]->_inflate_path( $_[ 1 ], qw(appldir bin) );
 
    return -d $dir ? $dir : untaint_path $Config{installsitescript};
 }
 
 sub _build_ctlfile {
-   my ($self, $attr) = @_; my $file = $self->name.$self->extension;
+   my $name      = $_[ 0 ]->_inflate_symbol( $_[ 1 ], q(name)      );
+   my $extension = $_[ 0 ]->_inflate_symbol( $_[ 1 ], q(extension) );
 
-   return $self->_inflate_path( $attr, q(ctrldir), $file );
+   return $_[ 0 ]->_inflate_path( $_[ 1 ], q(ctrldir), $name.$extension );
 }
 
 sub _build_ctrldir {
@@ -156,38 +153,36 @@ sub _build_dbasedir {
    return -d $dir ? $dir : $_[ 0 ]->_inflate_path( $_[ 1 ], q(vardir) );
 }
 
-sub _build_localedir {
-   my ($self, $attr) = @_;
+sub _build_extension {
+   return CONFIG_EXTN;
+}
 
-   my $dir = $self->_inflate_path( $attr, qw(vardir locale) );
+sub _build_localedir {
+   my $dir = $_[ 0 ]->_inflate_path( $_[ 1 ], qw(vardir locale) );
 
    -d $dir and return $dir;
 
    for (map { catdir( @{ $_ } ) } @{ DIRECTORIES() } ) { -d $_ and return $_ }
 
-   return $self->_inflate_path( $attr, qw(tempdir) );
+   return $_[ 0 ]->_inflate_path( $_[ 1 ], qw(tempdir) );
 }
 
 sub _build_logfile {
-   return $_[ 0 ]->_inflate_path( $_[ 1 ], q(logsdir), $_[ 0 ]->name.q(.log) );
+   my $name = $_[ 0 ]->_inflate_symbol( $_[ 1 ], q(name) );
+
+   return $_[ 0 ]->_inflate_path( $_[ 1 ], q(logsdir), "${name}.log" );
 }
 
 sub _build_logsdir {
-   my ($self, $attr) = @_;
+   my $dir = $_[ 0 ]->_inflate_path( $_[ 1 ], qw(vardir logs) );
 
-   my $dir = $self->_inflate_path( $attr, qw(vardir logs) );
-
-   return -d $dir ? $dir : $self->_inflate_path( $attr, qw(tempdir) );
+   return -d $dir ? $dir : $_[ 0 ]->_inflate_path( $_[ 1 ], qw(tempdir) );
 }
 
 sub _build_name {
-   my $prog = basename( $_[ 0 ]->pathname, EXTNS );
+   my $name = basename( $_[ 0 ]->_inflate_path( $_[ 1 ], q(pathname) ), EXTNS );
 
-   return (split_on__ $prog, 1) || $prog;
-}
-
-sub _build_owner {
-   return $_[ 0 ]->prefix || q(root);
+   return (split_on__ $name, 1) || $name;
 }
 
 sub _build_pathname {
@@ -200,17 +195,16 @@ sub _build_path_to {
 }
 
 sub _build_phase {
-   my ($self, $attr) = @_;
-
-   my $verdir  = blessed $self ? basename( $self->appldir )
-               : basename( $self->_inflate_path( $attr, q(appldir) ) );
+   my $verdir  = basename( $_[ 0 ]->_inflate_path( $_[ 1 ], q(appldir) ) );
    my ($phase) = $verdir =~ m{ \A v \d+ \. \d+ p (\d+) \z }msx;
 
    return defined $phase ? $phase : PHASE;
 }
 
 sub _build_prefix {
-   return (split m{ :: }mx, lc $_[ 0 ]->appclass)[ -1 ];
+   my $appclass = $_[ 0 ]->_inflate_symbol( $_[ 1 ], q(appclass) );
+
+   return (split m{ :: }mx, lc $appclass)[ -1 ];
 }
 
 sub _build_root {
@@ -225,12 +219,8 @@ sub _build_rundir {
    return -d $dir ? $dir : $_[ 0 ]->_inflate_path( $_[ 1 ], q(vardir) );
 }
 
-sub _build_script {
-   return basename( $_[ 0 ]->pathname );
-}
-
 sub _build_salt {
-   return $_[ 0 ]->prefix;
+   return $_[ 0 ]->_inflate_symbol( $_[ 1 ], q(prefix) );
 }
 
 sub _build_sessdir {
@@ -248,9 +238,9 @@ sub _build_shell {
 }
 
 sub _build_suid {
-   my ($self, $attr) = @_; my $file = $self->prefix.q(_admin);
+   my $prefix = $_[ 0 ]->_inflate_symbol( $_[ 1 ], q(prefix) );
 
-   return $self->_inflate_path( $attr, q(binsdir), $file );
+   return $_[ 0 ]->_inflate_path( $_[ 1 ], q(binsdir), "${prefix}_admin" );
 }
 
 sub _build_tempdir {
@@ -260,23 +250,19 @@ sub _build_tempdir {
 }
 
 sub _build_vardir {
-   my ($self, $attr) = @_;
+   my $dir = $_[ 0 ]->_inflate_path( $_[ 1 ], qw(appldir var) );
 
-   my $dir = $self->_inflate_path( $attr, qw(appldir var) );
-
-   return -d $dir ? $dir : $self->_inflate_path( $attr, q(appldir) );
+   return -d $dir ? $dir : $_[ 0 ]->_inflate_path( $_[ 1 ], q(appldir) );
 }
 
 sub _inflate_path {
-   my ($self, $attr, $symbol, $relpath) = @_; $attr ||= {}; $relpath ||= NUL;
+   my ($self, $attr, $symbol, $relpath) = @_; $attr ||= {};
 
-   my $base  = $self->_inflate_symbol( $attr, $symbol );
+   my $inflated = $self->_inflate_symbol( $attr, $symbol );
 
-   my @parts = ($base, split m{ / }mx, $relpath);
+   $relpath or return canonpath( untaint_path $inflated );
 
-   my $path  = catdir( @parts ); -d $path or $path = catfile( @parts );
-
-   return untaint_path canonpath( $path );
+   return $self->canonicalise( $inflated, $relpath );
 }
 
 sub _inflate_symbol {
@@ -320,7 +306,7 @@ Class::Usul::Config - Inflate config values
 
 =head1 Version
 
-Describes Class::Usul::Config version 0.8.$Revision: 206 $
+Describes Class::Usul::Config version 0.9.$Revision: 223 $
 
 =head1 Synopsis
 
@@ -335,53 +321,6 @@ Defines the following list of attributes
 Required string. The classname of the application for which this is the
 configuration class
 
-=item C<doc_title>
-
-String defaults to 'User Contributed Documentation'. Used in the Unix man
-pages
-
-=item C<encoding>
-
-String default to the constant I<DEFAULT_ENCODING>
-
-=item C<extension>
-
-String defaults to the constant I<CONFIG_EXTN>
-
-=item C<home>
-
-Directory containing the config file. Required
-
-=item C<l10n_attributes>
-
-Hash ref of attributes used to construct a L<Class::Usul::L10N> object
-
-=item C<lock_attributes>
-
-Hash ref of attributes used to construct an L<IPC::SRLock> object
-
-=item C<log_attributes>
-
-Hash ref of attributes used to construct a L<Class::Usul::Log> object
-
-=item C<man_page_cmd>
-
-Array ref containing the command and options to produce a man page. Defaults
-to I<man -nroff>
-
-=item C<mode>
-
-Integer defaults to the constant I<PERMS>. The default file creation mask
-
-=item C<no_thrash>
-
-Integer default to 3. Number of seconds to sleep in a polling loop to
-avoid processor thrash
-
-=item C<pathname>
-
-File defaults to the absolute path to the I<PROGRAM_NAME> system constant
-
 =item C<appldir>
 
 Directory. Defaults to the application's install directory
@@ -402,11 +341,35 @@ Directory containing the per program configuration files
 
 Directory containing the data file used to create the applications database
 
+=item C<encoding>
+
+String default to the constant I<DEFAULT_ENCODING>
+
+=item C<extension>
+
+String defaults to the constant I<CONFIG_EXTN>
+
+=item C<home>
+
+Directory containing the config file. Required
+
+=item C<l10n_attributes>
+
+Hash ref of attributes used to construct a L<Class::Usul::L10N> object
+
 =item C<localedir>
 
 Directory containing the GNU Gettext portable object files used to translate
 messages into different languages
 
+=item C<lock_attributes>
+
+Hash ref of attributes used to construct an L<IPC::SRLock> object
+
+=item C<log_attributes>
+
+Hash ref of attributes used to construct a L<Class::Usul::Log> object
+
 =item C<logfile>
 
 File in the C<logsdir> to which this program will log
@@ -415,6 +378,28 @@ File in the C<logsdir> to which this program will log
 
 Directory containing the application log files
 
+=item C<name>
+
+String. Name of the program
+
+=item C<no_thrash>
+
+Integer default to 3. Number of seconds to sleep in a polling loop to
+avoid processor thrash
+
+=item C<pathname>
+
+File defaults to the absolute path to the I<PROGRAM_NAME> system constant
+
+=item C<phase>
+
+Integer. Phase number indicates the type of install, e.g. 1 live, 2 test,
+3 development
+
+=item C<prefix>
+
+String. Program prefix
+
 =item C<root>
 
 Directory. Path to the web applications document root
@@ -423,6 +408,12 @@ Directory. Path to the web applications document root
 
 Directory. Contains a running programs PID file
 
+=item C<salt>
+
+String. This applications salt for passwords as set by the administrators . It
+is used to perturb the encryption methods. Defaults to the I<prefix>
+attribute value
+
 =item C<sessdir>
 
 Directory. The session directory
@@ -445,33 +436,6 @@ application. Defaults to the L<File::Spec> tempdir
 
 Directory. Contains all of the non program code directories
 
-=item C<name>
-
-String. Name of the program
-
-=item C<owner>
-
-String. Name of the application file owner
-
-=item C<phase>
-
-Integer. Phase number indicates the type of install, e.g. 1 live, 2 test,
-3 development
-
-=item C<prefix>
-
-String. Program prefix
-
-=item C<script>
-
-String. The basename of the I<pathname> attribute
-
-=item C<salt>
-
-String. This applications salt for passwords as set by the administrators . It
-is used to perturb the encryption methods. Defaults to the I<prefix>
-attribute value
-
 =back
 
 =head1 Subroutines/Methods
@@ -481,6 +445,14 @@ attribute value
 Loads the configuration files if specified. Calls L</inflate_symbol>
 and L</inflate_path>
 
+=head2 canonicalise
+
+   $untainted_canonpath = $self->canonicalise( $base, $relpath );
+
+Appends C<$relpath> to C<$base> using L<File::Spec::Functions>. The C<$base>
+argument can be an array ref or a scalar. The C<$relpath> argument must be
+separated by slashes. The return path is untainted and canonicalised
+
 =head2 _inflate_path
 
 Inflates the I<__symbol( relative_path )__> values to their actual runtime
