@@ -1,9 +1,9 @@
-# @(#)$Id: IPC.pm 207 2012-09-07 12:40:55Z pjf $
+# @(#)$Id: IPC.pm 223 2012-10-31 01:24:47Z pjf $
 
 package Class::Usul::IPC;
 
 use strict;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 207 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 223 $ =~ /\d+/gmx );
 
 use Class::Null;
 use Class::Usul::Moose;
@@ -236,7 +236,7 @@ sub _new_process_table {
 
    return $self->table_class->new
       ( count    => $count,
-        flds     => [ qw(uid pid ppid start time size state tty cmd) ],
+        fields   => [ qw(uid pid ppid start time size state tty cmd) ],
         labels   => { uid   => 'User',   pid   => 'PID',
                       ppid  => 'PPID',   start => 'Start Time',
                       tty   => 'TTY',    time  => 'Time',
@@ -501,7 +501,7 @@ sub __partition_command {
    my $cmd = shift; my $aref = []; my @command = ();
 
    for my $item (grep { defined && length } @{ $cmd }) {
-      if ($item !~ m{ [\<\>\|\&] }mx) { push @{ $aref }, $item }
+      if ($item !~ m{ [^\\][\<\>\|\&] }mx) { push @{ $aref }, $item }
       else { push @command, $aref, $item; $aref = [] }
    }
 
@@ -552,7 +552,7 @@ Class::Usul::IPC - List/Create/Delete processes
 
 =head1 Version
 
-0.8.$Revision: 207 $
+0.9.$Revision: 223 $
 
 =head1 Synopsis
 
